# itkwidgets

[![Documentation Status](https://readthedocs.org/projects/itkwidgets/badge/?version=latest)](https://itkwidgets.readthedocs.io/en/latest/?badge=latest)

Interactive widgets to visualize images, point sets, and 3D geometry on the web.

Check out the [Quick Start Guide](https://itkwidgets.readthedocs.io/en/latest/quick_start_guide.html) if you're ready to get started or visit the [docs](https://itkwidgets.readthedocs.io/en/latest/) for more information.
